containertools.repeat_last_n_elements_of_container
==================================================

.. autofunction:: abjad.tools.containertools.repeat_last_n_elements_of_container.repeat_last_n_elements_of_container
